@@ -14,8 +14,8 @@ my $diamonds = diamonds();
 
 my $p = ggplot(
     data    => $diamonds,
-    mapping => aes( x => 'cut', y => 'price' )
-)->geom_boxplot()->coord_flip();
+    mapping => aes( x => 'carat' )
+)->geom_histogram()->coord_flip();
 
 if (defined $save_as) {
     $p->save($save_as);
