@@ -26,7 +26,7 @@ my $p = ggplot( data => $mtcars2 )
     y        => 'Fuel economy (mpg)',
     color    => 'Gears',
   )
-  ->theme_void();
+  ->theme_bw();
 
 if ( defined $save_as ) {
     $p->save($save_as);
